@@ -12,7 +12,7 @@ data.combined <- rbind(lin, data.combined)
 
 # This may stop working once we filter uninteresting values in the C code directly.
 DIFF <- eaf:::compute.eafdiff.helper(data.combined, intervals = nruns.left)
-x <- as.matrix(read.table("lin.S-sph.S-diff.txt", header = FALSE))
+x <- as.matrix(read.table("lin.S-sph.S-diff.txt.xz", header = FALSE))
 dimnames(x) <- NULL
 x[, nobjs + 1] <- x[, nobjs + 1] - x[, nobjs + 2]
 stopifnot(all.equal(DIFF[, 1 : (nobjs + 1)], x[, 1 : (nobjs + 1)]))
